privacy_lens library

Classes

PrivacyLens
A widget that protects sensitive content by applying a blur filter. PrivacyLens can automatically blur content when the app lifecycle changes to inactive/paused, or it can be manually triggered via isProtected.